==> scipion-em-chimera-3.0.1.tar.gz: scipion-em-chimera-3.0.1/chimera/bibtex.py <==
# coding: utf-8
# **************************************************************************
# *
# * Authors:     Roberto Marabini (roberto@cnb.csic.es)
# *
# * L'Institut de genetique et de biologie moleculaire et cellulaire (IGBMC)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
"""
@article{Pettersen2004,
   Author="Pettersen, E. F.  and Goddard, T. D.  and Huang, C. C.  and Couch, G. S.  and Greenblatt, D. M.  and Meng, E. C.  and Ferrin, T. E. ",
   Title="{{U}{C}{S}{F} {C}himera--a visualization system for exploratory research and analysis}",
   Journal="J Comput Chem",
   Year="2004",
   Volume="25",
   Number="13",
   Pages="1605--1612",
   Month="Oct",
   doi="http://doi.org/10.1002/jcc.20084",
   url = "http://onlinelibrary.wiley.com/doi/abs/10.1002/jcc.20084"
}
"""

==> scipion-em-chimera-3.0.3.tar.gz: scipion-em-chimera-3.0.3/chimera/bibtex.py <==
# coding: utf-8
# **************************************************************************
# *
# * Authors:     Roberto Marabini (roberto@cnb.csic.es)
# *
# * L'Institut de genetique et de biologie moleculaire et cellulaire (IGBMC)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
"""
@Article{Goddard2018,
   Author="Goddard, T. D.  and Huang, C. C.  and Meng, E. C.  and Pettersen, E. F.  and Couch, G. S.  and Morris, J. H.  and Ferrin, T. E. ",
   Title="{{U}{C}{S}{F} {C}himera{X}: {M}eeting modern challenges in visualization and analysis}",
   Journal="Protein Sci.",
   Year="2018",
   Volume="27",
   Number="1",
   Pages="14--25",
   Month="01",
   doi = "https://doi.org/10.1002/pro.3235",
   url = "https://onlinelibrary.wiley.com/doi/full/10.1002/pro.3235"
}
"""
